/*
 *                   jfjji,.           H A M M E R H E A D  S H A R K W A R E
 *                  ,#######EL:                  http://www.hhsw.de
 *                   .,j######Kj       
 *                    ;W########G:     This  code  is  free software; you can
 *                   j#####G ,D#L:     redistribute it and/or modify it under
 *             .,;;,G#####D.           the  terms  of  the GNU General Public
 *           jE##########G             License   as  published  by  the  Free
 *             .,W######D.             Software  Foundation; either version 2
 *             :L#####K##G             of  the  License,  or (at your option)
 *           .f#####G;.t##:            any later version.
 *         ;L###ELi.    ,D,            
 *       iEEGWj                        This  code  is distributed in the hope
 *      tW;                            that  it  will  be useful, but without
 *     jf                              any warranty; without even the implied
 *    .Kt                              warranty of merchantability or fitness
 *    i:                               for  a particular purpose. See the GNU
 *    ;                                General   Public   License   for  more
 *    .                                details (http://www.gnu.org).
 */
#ifndef bbdock_Slot_hh
#define bbdock_Slot_hh

#include <unistd.h>
#include <string>

#include <X11/Xlib.h>
#include <X11/xpm.h>
#include <X11/Xutil.h>
#include <X11/extensions/shape.h>

#include <png.h>

#include "Dock.hh"
#include "Icon.hh"
#include "Render.hh"

namespace bbdock
{
	/**
	 * Shows an icon in the BlackBox slit from wich the user
	 * can launch a corresponding application
	 *
	 * @author mf@hhsw.de
	 * @version 0.06
	 */
	class Slot
	{
		public:
			inline const Window &getWindow() const { return window; }
			inline Slot *getNext() const { return next; }
			inline const char *getIcon() const { 
				return icon->getImage().c_str(); }
			inline const char *getCommand() const { 
				return icon->getCommand().c_str(); }
			inline const void setVisibility( int s ) { visibility = s; }
			inline const void invalidate() { invalid = true; }

			Slot( Dock &, Icon &, Slot * );
			virtual ~Slot();
			virtual void draw( bool = false );
			virtual void exec();
			virtual void tick();
			virtual void setIcon( const char * );

		protected:
			virtual void loadIcon();
			virtual void destroyIcon();
			virtual void createSurface();
			virtual void destorySurface();
			virtual void getBackground();

		private:
			enum
			{
				Half = 80,
				Full = 255
			};

			Dock	*dock;
			Icon	*icon;
			Slot	*next;
			Render	*render;
			Window	window;
			XImage	*surface;
			int		*iconimage;
			char	*image;
			char	*background;
			int		left;
			int		top;
			int		width;
			int		height;
			int		visibility;
			bool	invalid;
			int		pid;
			int		transparency;
	};
}

#endif
